# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_physicalgoods.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_physicalgoods.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!steammessages_physicalgoods.proto\x1a steammessages_unified_base.proto\"`\n.CPhysicalGoods_RegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"1\n/CPhysicalGoods_RegisterSteamController_Response\"l\n:CPhysicalGoods_CompleteSteamControllerRegistration_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"=\n;CPhysicalGoods_CompleteSteamControllerRegistration_Response\"h\n6CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"k\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15registration_complete\x18\x02 \x01(\x08\"\x85\x01\n7CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\x12J\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts\"~\n8CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\"\x88\x02\n/CPhysicalGoods_SteamControllerSetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12Q\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerSetConfig_ControllerConfig\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"2\n0CPhysicalGoods_SteamControllerSetConfig_Response\"\xca\x01\n/CPhysicalGoods_SteamControllerGetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12\x13\n\x0b\x61ppidorname\x18\x04 \x01(\t\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x95\x01\n8CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x04 \x01(\t\"\x85\x01\n0CPhysicalGoods_SteamControllerGetConfig_Response\x12Q\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32\x39.CPhysicalGoods_SteamControllerGetConfig_ControllerConfig\"u\n0CPhysicalGoods_DeRegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\"3\n1CPhysicalGoods_DeRegisterSteamController_Response\"r\n-CPhysicalGoods_SetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x11\n\taccountid\x18\x03 \x01(\r\"0\n.CPhysicalGoods_SetPersonalizationFile_Response\"Y\n-CPhysicalGoods_GetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x11\n\taccountid\x18\x02 \x01(\r\"I\n.CPhysicalGoods_GetPersonalizationFile_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\x32\xd7\x0c\n\rPhysicalGoods\x12\xd4\x01\n\x17RegisterSteamController\x12/.CPhysicalGoods_RegisterSteamController_Request\x1a\x30.CPhysicalGoods_RegisterSteamController_Response\"V\x82\xb5\x18RRecords a serial number and the calling user\'s account info for warranty purposes.\x12\xd3\x01\n#CompleteSteamControllerRegistration\x12;.CPhysicalGoods_CompleteSteamControllerRegistration_Request\x1a<.CPhysicalGoods_CompleteSteamControllerRegistration_Response\"1\x82\xb5\x18-Marks a controller\'s registration as complete\x12\xd7\x01\n#QueryAccountsRegisteredToController\x12\x37.CPhysicalGoods_QueryAccountsRegisteredToSerial_Request\x1a\x38.CPhysicalGoods_QueryAccountsRegisteredToSerial_Response\"=\x82\xb5\x18\x39Sends back a list of accounts registered to a controller.\x12\xb8\x01\n SetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerSetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerSetConfig_Response\"/\x82\xb5\x18+Sets a desired controller config for an app\x12\xb8\x01\n GetDesiredControllerConfigForApp\x12\x30.CPhysicalGoods_SteamControllerGetConfig_Request\x1a\x31.CPhysicalGoods_SteamControllerGetConfig_Response\"/\x82\xb5\x18+Gets a desired controller config for an app\x12\xa1\x01\n\x19\x44\x65RegisterSteamController\x12\x31.CPhysicalGoods_DeRegisterSteamController_Request\x1a\x32.CPhysicalGoods_DeRegisterSteamController_Response\"\x1d\x82\xb5\x18\x19\x44\x65 registers a controller\x12\xb7\x01\n SetControllerPersonalizationFile\x12..CPhysicalGoods_SetPersonalizationFile_Request\x1a/.CPhysicalGoods_SetPersonalizationFile_Response\"2\x82\xb5\x18.Stores the file ID of the personalization file\x12\xb5\x01\n GetControllerPersonalizationFile\x12..CPhysicalGoods_GetPersonalizationFile_Request\x1a/.CPhysicalGoods_GetPersonalizationFile_Response\"0\x82\xb5\x18,Gets the file ID of the personalization file\x1a\x33\x82\xb5\x18/A service to use physical goods related methodsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])




_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_RegisterSteamController_Request',
  full_name='CPhysicalGoods_RegisterSteamController_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_RegisterSteamController_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_RegisterSteamController_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=167,
)


_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_RegisterSteamController_Response',
  full_name='CPhysicalGoods_RegisterSteamController_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=218,
)


_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_CompleteSteamControllerRegistration_Request',
  full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=328,
)


_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_CompleteSteamControllerRegistration_Response',
  full_name='CPhysicalGoods_CompleteSteamControllerRegistration_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=391,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=497,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registration_complete', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts.registration_complete', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=606,
)


_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response',
  full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='CPhysicalGoods_QueryAccountsRegisteredToSerial_Response.accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=742,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig',
  full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.appidorname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='templatename', full_name='CPhysicalGoods_SteamControllerSetConfig_ControllerConfig.templatename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=870,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_Request',
  full_name='CPhysicalGoods_SteamControllerSetConfig_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configurations', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.configurations', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.controller_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_for_this_serial', full_name='CPhysicalGoods_SteamControllerSetConfig_Request.only_for_this_serial', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=1137,
)


_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerSetConfig_Response',
  full_name='CPhysicalGoods_SteamControllerSetConfig_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1139,
  serialized_end=1189,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_Request',
  full_name='CPhysicalGoods_SteamControllerGetConfig_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.appidorname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.controller_type', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_for_this_serial', full_name='CPhysicalGoods_SteamControllerGetConfig_Request.only_for_this_serial', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1394,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig',
  full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appidorname', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.appidorname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='templatename', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.templatename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SteamControllerGetConfig_ControllerConfig.serial_number', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1546,
)


_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SteamControllerGetConfig_Response',
  full_name='CPhysicalGoods_SteamControllerGetConfig_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configurations', full_name='CPhysicalGoods_SteamControllerGetConfig_Response.configurations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1682,
)


_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_DeRegisterSteamController_Request',
  full_name='CPhysicalGoods_DeRegisterSteamController_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_DeRegisterSteamController_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_code', full_name='CPhysicalGoods_DeRegisterSteamController_Request.controller_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_DeRegisterSteamController_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1684,
  serialized_end=1801,
)


_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_DeRegisterSteamController_Response',
  full_name='CPhysicalGoods_DeRegisterSteamController_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1854,
)


_CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_SetPersonalizationFile_Request',
  full_name='CPhysicalGoods_SetPersonalizationFile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_SetPersonalizationFile_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_SetPersonalizationFile_Request.publishedfileid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_SetPersonalizationFile_Request.accountid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=1970,
)


_CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_SetPersonalizationFile_Response',
  full_name='CPhysicalGoods_SetPersonalizationFile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2020,
)


_CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST = _descriptor.Descriptor(
  name='CPhysicalGoods_GetPersonalizationFile_Request',
  full_name='CPhysicalGoods_GetPersonalizationFile_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='CPhysicalGoods_GetPersonalizationFile_Request.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CPhysicalGoods_GetPersonalizationFile_Request.accountid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2111,
)


_CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE = _descriptor.Descriptor(
  name='CPhysicalGoods_GetPersonalizationFile_Response',
  full_name='CPhysicalGoods_GetPersonalizationFile_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='publishedfileid', full_name='CPhysicalGoods_GetPersonalizationFile_Response.publishedfileid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2113,
  serialized_end=2186,
)

_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE.fields_by_name['accounts'].message_type = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS
_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST.fields_by_name['configurations'].message_type = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG
_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE.fields_by_name['configurations'].message_type = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_RegisterSteamController_Request'] = _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_RegisterSteamController_Response'] = _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_CompleteSteamControllerRegistration_Request'] = _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_CompleteSteamControllerRegistration_Response'] = _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Request'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS
DESCRIPTOR.message_types_by_name['CPhysicalGoods_QueryAccountsRegisteredToSerial_Response'] = _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_ControllerConfig'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_Request'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerSetConfig_Response'] = _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_Request'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_ControllerConfig'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SteamControllerGetConfig_Response'] = _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_DeRegisterSteamController_Request'] = _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_DeRegisterSteamController_Response'] = _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SetPersonalizationFile_Request'] = _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_SetPersonalizationFile_Response'] = _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE
DESCRIPTOR.message_types_by_name['CPhysicalGoods_GetPersonalizationFile_Request'] = _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST
DESCRIPTOR.message_types_by_name['CPhysicalGoods_GetPersonalizationFile_Response'] = _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPhysicalGoods_RegisterSteamController_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_RegisterSteamController_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_RegisterSteamController_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_RegisterSteamController_Request)

CPhysicalGoods_RegisterSteamController_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_RegisterSteamController_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_RegisterSteamController_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_RegisterSteamController_Response)

CPhysicalGoods_CompleteSteamControllerRegistration_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_CompleteSteamControllerRegistration_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_CompleteSteamControllerRegistration_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_CompleteSteamControllerRegistration_Request)

CPhysicalGoods_CompleteSteamControllerRegistration_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_CompleteSteamControllerRegistration_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_CompleteSteamControllerRegistration_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_CompleteSteamControllerRegistration_Response)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Request)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Accounts)

CPhysicalGoods_QueryAccountsRegisteredToSerial_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_QueryAccountsRegisteredToSerial_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_QueryAccountsRegisteredToSerial_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_QueryAccountsRegisteredToSerial_Response)

CPhysicalGoods_SteamControllerSetConfig_ControllerConfig = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_ControllerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_ControllerConfig)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_ControllerConfig)

CPhysicalGoods_SteamControllerSetConfig_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_Request)

CPhysicalGoods_SteamControllerSetConfig_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerSetConfig_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerSetConfig_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerSetConfig_Response)

CPhysicalGoods_SteamControllerGetConfig_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_Request)

CPhysicalGoods_SteamControllerGetConfig_ControllerConfig = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_ControllerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_ControllerConfig)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_ControllerConfig)

CPhysicalGoods_SteamControllerGetConfig_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SteamControllerGetConfig_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SteamControllerGetConfig_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SteamControllerGetConfig_Response)

CPhysicalGoods_DeRegisterSteamController_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_DeRegisterSteamController_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_DeRegisterSteamController_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_DeRegisterSteamController_Request)

CPhysicalGoods_DeRegisterSteamController_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_DeRegisterSteamController_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_DeRegisterSteamController_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_DeRegisterSteamController_Response)

CPhysicalGoods_SetPersonalizationFile_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SetPersonalizationFile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SetPersonalizationFile_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SetPersonalizationFile_Request)

CPhysicalGoods_SetPersonalizationFile_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_SetPersonalizationFile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_SetPersonalizationFile_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_SetPersonalizationFile_Response)

CPhysicalGoods_GetPersonalizationFile_Request = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_GetPersonalizationFile_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_GetPersonalizationFile_Request)
  })
_sym_db.RegisterMessage(CPhysicalGoods_GetPersonalizationFile_Request)

CPhysicalGoods_GetPersonalizationFile_Response = _reflection.GeneratedProtocolMessageType('CPhysicalGoods_GetPersonalizationFile_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE,
  '__module__' : 'steammessages_physicalgoods_pb2'
  # @@protoc_insertion_point(class_scope:CPhysicalGoods_GetPersonalizationFile_Response)
  })
_sym_db.RegisterMessage(CPhysicalGoods_GetPersonalizationFile_Response)


DESCRIPTOR._options = None

_PHYSICALGOODS = _descriptor.ServiceDescriptor(
  name='PhysicalGoods',
  full_name='PhysicalGoods',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030/A service to use physical goods related methods',
  create_key=_descriptor._internal_create_key,
  serialized_start=2189,
  serialized_end=3812,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterSteamController',
    full_name='PhysicalGoods.RegisterSteamController',
    index=0,
    containing_service=None,
    input_type=_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_REQUEST,
    output_type=_CPHYSICALGOODS_REGISTERSTEAMCONTROLLER_RESPONSE,
    serialized_options=b'\202\265\030RRecords a serial number and the calling user\'s account info for warranty purposes.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteSteamControllerRegistration',
    full_name='PhysicalGoods.CompleteSteamControllerRegistration',
    index=1,
    containing_service=None,
    input_type=_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST,
    output_type=_CPHYSICALGOODS_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE,
    serialized_options=b'\202\265\030-Marks a controller\'s registration as complete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryAccountsRegisteredToController',
    full_name='PhysicalGoods.QueryAccountsRegisteredToController',
    index=2,
    containing_service=None,
    input_type=_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST,
    output_type=_CPHYSICALGOODS_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE,
    serialized_options=b'\202\265\0309Sends back a list of accounts registered to a controller.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDesiredControllerConfigForApp',
    full_name='PhysicalGoods.SetDesiredControllerConfigForApp',
    index=3,
    containing_service=None,
    input_type=_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_REQUEST,
    output_type=_CPHYSICALGOODS_STEAMCONTROLLERSETCONFIG_RESPONSE,
    serialized_options=b'\202\265\030+Sets a desired controller config for an app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDesiredControllerConfigForApp',
    full_name='PhysicalGoods.GetDesiredControllerConfigForApp',
    index=4,
    containing_service=None,
    input_type=_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_REQUEST,
    output_type=_CPHYSICALGOODS_STEAMCONTROLLERGETCONFIG_RESPONSE,
    serialized_options=b'\202\265\030+Gets a desired controller config for an app',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeRegisterSteamController',
    full_name='PhysicalGoods.DeRegisterSteamController',
    index=5,
    containing_service=None,
    input_type=_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_REQUEST,
    output_type=_CPHYSICALGOODS_DEREGISTERSTEAMCONTROLLER_RESPONSE,
    serialized_options=b'\202\265\030\031De registers a controller',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetControllerPersonalizationFile',
    full_name='PhysicalGoods.SetControllerPersonalizationFile',
    index=6,
    containing_service=None,
    input_type=_CPHYSICALGOODS_SETPERSONALIZATIONFILE_REQUEST,
    output_type=_CPHYSICALGOODS_SETPERSONALIZATIONFILE_RESPONSE,
    serialized_options=b'\202\265\030.Stores the file ID of the personalization file',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControllerPersonalizationFile',
    full_name='PhysicalGoods.GetControllerPersonalizationFile',
    index=7,
    containing_service=None,
    input_type=_CPHYSICALGOODS_GETPERSONALIZATIONFILE_REQUEST,
    output_type=_CPHYSICALGOODS_GETPERSONALIZATIONFILE_RESPONSE,
    serialized_options=b'\202\265\030,Gets the file ID of the personalization file',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PHYSICALGOODS)

DESCRIPTOR.services_by_name['PhysicalGoods'] = _PHYSICALGOODS

PhysicalGoods = service_reflection.GeneratedServiceType('PhysicalGoods', (_service.Service,), dict(
  DESCRIPTOR = _PHYSICALGOODS,
  __module__ = 'steammessages_physicalgoods_pb2'
  ))

PhysicalGoods_Stub = service_reflection.GeneratedServiceStubType('PhysicalGoods_Stub', (PhysicalGoods,), dict(
  DESCRIPTOR = _PHYSICALGOODS,
  __module__ = 'steammessages_physicalgoods_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_credentials.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_credentials.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"q\n*CCredentials_TestAvailablePassword_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x1b\n\x13sha_digest_password\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x03 \x01(\t\"?\n+CCredentials_TestAvailablePassword_Response\x12\x10\n\x08is_valid\x18\x03 \x01(\x08\"\x9e\x03\n)CCredentials_GetSteamGuardDetails_Request\x12u\n\x1binclude_new_authentications\x18\x01 \x01(\x08:\x04trueBJ\x82\xb5\x18\x46Whether or not to populate the newauthentication field in the response\x12\x95\x01\n\twebcookie\x18\x02 \x01(\tB\x81\x01\x82\xb5\x18}The user\'s Steam Guard machine auth cookie. If present, it\'ll be used to get the user\'s machine ID instead of the AM session.\x12 \n\x18timestamp_minimum_wanted\x18\x03 \x01(\x07\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x04 \x01(\x05\x12\"\n\nip_address\x18\x05 \x01(\x0b\x32\x0e.CMsgIPAddress\"\xb3\t\n*CCredentials_GetSteamGuardDetails_Response\x12\x1d\n\x15is_steamguard_enabled\x18\x01 \x01(\x08\x12$\n\x1ctimestamp_steamguard_enabled\x18\x02 \x01(\x07\x12\x63\n\x1c\x64\x65precated_newauthentication\x18\x03 \x03(\x0b\x32=.CCredentials_GetSteamGuardDetails_Response.NewAuthentication\x12*\n\"deprecated_machine_name_userchosen\x18\x04 \x01(\t\x12\x37\n/deprecated_timestamp_machine_steamguard_enabled\x18\x05 \x01(\x07\x12\x43\n;deprecated_authentication_exists_from_geoloc_before_mintime\x18\x06 \x01(\x08\x12\x1d\n\x15\x64\x65precated_machine_id\x18\x07 \x01(\x04\x12M\n\x0csession_data\x18\x08 \x03(\x0b\x32\x37.CCredentials_GetSteamGuardDetails_Response.SessionData\x12\x1c\n\x14is_twofactor_enabled\x18\t \x01(\x08\x12#\n\x1btimestamp_twofactor_enabled\x18\n \x01(\x07\x12\x19\n\x11is_phone_verified\x18\x0b \x01(\x08\x1a\xf2\x01\n\x11NewAuthentication\x12$\n\x1ctimestamp_steamguard_enabled\x18\x01 \x01(\x07\x12\x15\n\ris_web_cookie\x18\x02 \x01(\x08\x12\x1c\n\x14\x64\x65precated_ipaddress\x18\x03 \x01(\x05\x12\x13\n\x0bgeoloc_info\x18\x04 \x01(\t\x12\x15\n\ris_remembered\x18\x05 \x01(\x08\x12\"\n\x1amachine_name_user_supplied\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\x05\x12\"\n\nip_address\x18\x08 \x01(\x0b\x32\x0e.CMsgIPAddress\x1a\xef\x02\n\x0bSessionData\x12\x12\n\nmachine_id\x18\x01 \x01(\x04\x12\x1f\n\x17machine_name_userchosen\x18\x02 \x01(\t\x12,\n$timestamp_machine_steamguard_enabled\x18\x03 \x01(\x07\x12\x38\n0authentication_exists_from_geoloc_before_mintime\x18\x04 \x01(\x08\x12X\n\x11newauthentication\x18\x05 \x03(\x0b\x32=.CCredentials_GetSteamGuardDetails_Response.NewAuthentication\x12\x39\n1authentication_exists_from_same_ip_before_mintime\x18\x06 \x01(\x08\x12\x13\n\x0bpublic_ipv4\x18\x07 \x01(\r\x12\x19\n\x11public_ip_address\x18\x08 \x01(\t\"d\n1CCredentials_NewMachineNotificationDialog_Request\x12\x13\n\x0bis_approved\x18\x01 \x01(\x08\x12\x1a\n\x12is_wizard_complete\x18\x02 \x01(\x08\"4\n2CCredentials_NewMachineNotificationDialog_Response\";\n)CCredentials_ValidateEmailAddress_Request\x12\x0e\n\x06stoken\x18\x01 \x01(\t\"C\n*CCredentials_ValidateEmailAddress_Response\x12\x15\n\rwas_validated\x18\x01 \x01(\x08\"_\n-CCredentials_SteamGuardPhishingReport_Request\x12\x14\n\x0cparam_string\x18\x01 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x02 \x01(\t\"\xb3\x02\n.CCredentials_SteamGuardPhishingReport_Response\x12\x1e\n\x16ipaddress_loginattempt\x18\x01 \x01(\t\x12 \n\x18\x63ountryname_loginattempt\x18\x02 \x01(\t\x12\x1e\n\x16statename_loginattempt\x18\x03 \x01(\t\x12\x1d\n\x15\x63ityname_loginattempt\x18\x04 \x01(\t\x12\x18\n\x10ipaddress_actual\x18\x05 \x01(\t\x12\x1a\n\x12\x63ountryname_actual\x18\x06 \x01(\t\x12\x18\n\x10statename_actual\x18\x07 \x01(\t\x12\x17\n\x0f\x63ityname_actual\x18\x08 \x01(\t\x12\x17\n\x0fsteamguard_code\x18\t \x01(\t\"J\n-CCredentials_LastCredentialChangeTime_Request\x12\x19\n\x11user_changes_only\x18\x01 \x01(\x08\"\xa4\x01\n.CCredentials_LastCredentialChangeTime_Response\x12&\n\x1etimestamp_last_password_change\x18\x01 \x01(\x07\x12#\n\x1btimestamp_last_email_change\x18\x02 \x01(\x07\x12%\n\x1dtimestamp_last_password_reset\x18\x03 \x01(\x07\"+\n)CCredentials_GetAccountAuthSecret_Request\"O\n*CCredentials_GetAccountAuthSecret_Response\x12\x11\n\tsecret_id\x18\x01 \x01(\x05\x12\x0e\n\x06secret\x18\x02 \x01(\x0c\x32\xed\x08\n\x0b\x43redentials\x12\x8e\x01\n\x15TestAvailablePassword\x12+.CCredentials_TestAvailablePassword_Request\x1a,.CCredentials_TestAvailablePassword_Response\"\x1a\x82\xb5\x18\x16TestAvailablePassword.\x12\x8a\x01\n\x14GetSteamGuardDetails\x12*.CCredentials_GetSteamGuardDetails_Request\x1a+.CCredentials_GetSteamGuardDetails_Response\"\x19\x82\xb5\x18\x15GetSteamGuardDetails.\x12\xb6\x01\n\"NewMachineNotificationDialogResult\x12\x32.CCredentials_NewMachineNotificationDialog_Request\x1a\x33.CCredentials_NewMachineNotificationDialog_Response\"\'\x82\xb5\x18#NewMachineNotificationDialogResult.\x12\x9c\x01\n\x14ValidateEmailAddress\x12*.CCredentials_ValidateEmailAddress_Request\x1a+.CCredentials_ValidateEmailAddress_Response\"+\x82\xb5\x18\'Validate an email address given a token\x12\x99\x01\n\x18SteamGuardPhishingReport\x12..CCredentials_SteamGuardPhishingReport_Request\x1a/.CCredentials_SteamGuardPhishingReport_Response\"\x1c\x82\xb5\x18\x18SteamGuardPhishingReport\x12\xa6\x01\n\x1eGetCredentialChangeTimeDetails\x12..CCredentials_LastCredentialChangeTime_Request\x1a/.CCredentials_LastCredentialChangeTime_Response\"#\x82\xb5\x18\x1fGetCredentialChangeTimeDetails.\x12\x89\x01\n\x14GetAccountAuthSecret\x12*.CCredentials_GetAccountAuthSecret_Request\x1a+.CCredentials_GetAccountAuthSecret_Response\"\x18\x82\xb5\x18\x14GetAccountAuthSecret\x1a\x17\x82\xb5\x18\x13\x43redentials serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST = _descriptor.Descriptor(
  name='CCredentials_TestAvailablePassword_Request',
  full_name='CCredentials_TestAvailablePassword_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='CCredentials_TestAvailablePassword_Request.password', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_digest_password', full_name='CCredentials_TestAvailablePassword_Request.sha_digest_password', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_name', full_name='CCredentials_TestAvailablePassword_Request.account_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=208,
)


_CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_TestAvailablePassword_Response',
  full_name='CCredentials_TestAvailablePassword_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_valid', full_name='CCredentials_TestAvailablePassword_Response.is_valid', index=0,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=273,
)


_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST = _descriptor.Descriptor(
  name='CCredentials_GetSteamGuardDetails_Request',
  full_name='CCredentials_GetSteamGuardDetails_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_new_authentications', full_name='CCredentials_GetSteamGuardDetails_Request.include_new_authentications', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030FWhether or not to populate the newauthentication field in the response', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webcookie', full_name='CCredentials_GetSteamGuardDetails_Request.webcookie', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030}The user\'s Steam Guard machine auth cookie. If present, it\'ll be used to get the user\'s machine ID instead of the AM session.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_minimum_wanted', full_name='CCredentials_GetSteamGuardDetails_Request.timestamp_minimum_wanted', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_ipaddress', full_name='CCredentials_GetSteamGuardDetails_Request.deprecated_ipaddress', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='CCredentials_GetSteamGuardDetails_Request.ip_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=690,
)


_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION = _descriptor.Descriptor(
  name='NewAuthentication',
  full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.timestamp_steamguard_enabled', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_web_cookie', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.is_web_cookie', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_ipaddress', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.deprecated_ipaddress', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geoloc_info', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.geoloc_info', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_remembered', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.is_remembered', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name_user_supplied', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.machine_name_user_supplied', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.status', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='CCredentials_GetSteamGuardDetails_Response.NewAuthentication.ip_address', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1526,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA = _descriptor.Descriptor(
  name='SessionData',
  full_name='CCredentials_GetSteamGuardDetails_Response.SessionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_id', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.machine_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name_userchosen', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.machine_name_userchosen', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_machine_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.timestamp_machine_steamguard_enabled', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication_exists_from_geoloc_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.authentication_exists_from_geoloc_before_mintime', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newauthentication', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.newauthentication', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication_exists_from_same_ip_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.authentication_exists_from_same_ip_before_mintime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ipv4', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.public_ipv4', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_ip_address', full_name='CCredentials_GetSteamGuardDetails_Response.SessionData.public_ip_address', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1896,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_GetSteamGuardDetails_Response',
  full_name='CCredentials_GetSteamGuardDetails_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.is_steamguard_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.timestamp_steamguard_enabled', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_newauthentication', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_newauthentication', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_machine_name_userchosen', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_machine_name_userchosen', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_timestamp_machine_steamguard_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_timestamp_machine_steamguard_enabled', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_authentication_exists_from_geoloc_before_mintime', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_authentication_exists_from_geoloc_before_mintime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated_machine_id', full_name='CCredentials_GetSteamGuardDetails_Response.deprecated_machine_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_data', full_name='CCredentials_GetSteamGuardDetails_Response.session_data', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_twofactor_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.is_twofactor_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_twofactor_enabled', full_name='CCredentials_GetSteamGuardDetails_Response.timestamp_twofactor_enabled', index=9,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_phone_verified', full_name='CCredentials_GetSteamGuardDetails_Response.is_phone_verified', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION, _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=1896,
)


_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST = _descriptor.Descriptor(
  name='CCredentials_NewMachineNotificationDialog_Request',
  full_name='CCredentials_NewMachineNotificationDialog_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_approved', full_name='CCredentials_NewMachineNotificationDialog_Request.is_approved', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wizard_complete', full_name='CCredentials_NewMachineNotificationDialog_Request.is_wizard_complete', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1898,
  serialized_end=1998,
)


_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_NewMachineNotificationDialog_Response',
  full_name='CCredentials_NewMachineNotificationDialog_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2000,
  serialized_end=2052,
)


_CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST = _descriptor.Descriptor(
  name='CCredentials_ValidateEmailAddress_Request',
  full_name='CCredentials_ValidateEmailAddress_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stoken', full_name='CCredentials_ValidateEmailAddress_Request.stoken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2054,
  serialized_end=2113,
)


_CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_ValidateEmailAddress_Response',
  full_name='CCredentials_ValidateEmailAddress_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='was_validated', full_name='CCredentials_ValidateEmailAddress_Response.was_validated', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2182,
)


_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST = _descriptor.Descriptor(
  name='CCredentials_SteamGuardPhishingReport_Request',
  full_name='CCredentials_SteamGuardPhishingReport_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='param_string', full_name='CCredentials_SteamGuardPhishingReport_Request.param_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress_actual', full_name='CCredentials_SteamGuardPhishingReport_Request.ipaddress_actual', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2184,
  serialized_end=2279,
)


_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_SteamGuardPhishingReport_Response',
  full_name='CCredentials_SteamGuardPhishingReport_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipaddress_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.ipaddress_loginattempt', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countryname_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.countryname_loginattempt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statename_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.statename_loginattempt', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cityname_loginattempt', full_name='CCredentials_SteamGuardPhishingReport_Response.cityname_loginattempt', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipaddress_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.ipaddress_actual', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countryname_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.countryname_actual', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statename_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.statename_actual', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cityname_actual', full_name='CCredentials_SteamGuardPhishingReport_Response.cityname_actual', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamguard_code', full_name='CCredentials_SteamGuardPhishingReport_Response.steamguard_code', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2589,
)


_CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST = _descriptor.Descriptor(
  name='CCredentials_LastCredentialChangeTime_Request',
  full_name='CCredentials_LastCredentialChangeTime_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_changes_only', full_name='CCredentials_LastCredentialChangeTime_Request.user_changes_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=2665,
)


_CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_LastCredentialChangeTime_Response',
  full_name='CCredentials_LastCredentialChangeTime_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_last_password_change', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_password_change', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_last_email_change', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_email_change', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_last_password_reset', full_name='CCredentials_LastCredentialChangeTime_Response.timestamp_last_password_reset', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2668,
  serialized_end=2832,
)


_CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST = _descriptor.Descriptor(
  name='CCredentials_GetAccountAuthSecret_Request',
  full_name='CCredentials_GetAccountAuthSecret_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2834,
  serialized_end=2877,
)


_CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE = _descriptor.Descriptor(
  name='CCredentials_GetAccountAuthSecret_Response',
  full_name='CCredentials_GetAccountAuthSecret_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret_id', full_name='CCredentials_GetAccountAuthSecret_Response.secret_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='CCredentials_GetAccountAuthSecret_Response.secret', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2879,
  serialized_end=2958,
)

_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION.fields_by_name['ip_address'].message_type = steammessages__base__pb2._CMSGIPADDRESS
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION.containing_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA.fields_by_name['newauthentication'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA.containing_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE.fields_by_name['deprecated_newauthentication'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION
_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE.fields_by_name['session_data'].message_type = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA
DESCRIPTOR.message_types_by_name['CCredentials_TestAvailablePassword_Request'] = _CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_TestAvailablePassword_Response'] = _CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_GetSteamGuardDetails_Request'] = _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_GetSteamGuardDetails_Response'] = _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_NewMachineNotificationDialog_Request'] = _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_NewMachineNotificationDialog_Response'] = _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_ValidateEmailAddress_Request'] = _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_ValidateEmailAddress_Response'] = _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_SteamGuardPhishingReport_Request'] = _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_SteamGuardPhishingReport_Response'] = _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_LastCredentialChangeTime_Request'] = _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_LastCredentialChangeTime_Response'] = _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE
DESCRIPTOR.message_types_by_name['CCredentials_GetAccountAuthSecret_Request'] = _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST
DESCRIPTOR.message_types_by_name['CCredentials_GetAccountAuthSecret_Response'] = _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CCredentials_TestAvailablePassword_Request = _reflection.GeneratedProtocolMessageType('CCredentials_TestAvailablePassword_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_TestAvailablePassword_Request)
  })
_sym_db.RegisterMessage(CCredentials_TestAvailablePassword_Request)

CCredentials_TestAvailablePassword_Response = _reflection.GeneratedProtocolMessageType('CCredentials_TestAvailablePassword_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_TestAvailablePassword_Response)
  })
_sym_db.RegisterMessage(CCredentials_TestAvailablePassword_Response)

CCredentials_GetSteamGuardDetails_Request = _reflection.GeneratedProtocolMessageType('CCredentials_GetSteamGuardDetails_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Request)
  })
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Request)

CCredentials_GetSteamGuardDetails_Response = _reflection.GeneratedProtocolMessageType('CCredentials_GetSteamGuardDetails_Response', (_message.Message,), {

  'NewAuthentication' : _reflection.GeneratedProtocolMessageType('NewAuthentication', (_message.Message,), {
    'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_NEWAUTHENTICATION,
    '__module__' : 'steammessages_credentials_pb2'
    # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response.NewAuthentication)
    })
  ,

  'SessionData' : _reflection.GeneratedProtocolMessageType('SessionData', (_message.Message,), {
    'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE_SESSIONDATA,
    '__module__' : 'steammessages_credentials_pb2'
    # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response.SessionData)
    })
  ,
  'DESCRIPTOR' : _CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetSteamGuardDetails_Response)
  })
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response)
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response.NewAuthentication)
_sym_db.RegisterMessage(CCredentials_GetSteamGuardDetails_Response.SessionData)

CCredentials_NewMachineNotificationDialog_Request = _reflection.GeneratedProtocolMessageType('CCredentials_NewMachineNotificationDialog_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_NewMachineNotificationDialog_Request)
  })
_sym_db.RegisterMessage(CCredentials_NewMachineNotificationDialog_Request)

CCredentials_NewMachineNotificationDialog_Response = _reflection.GeneratedProtocolMessageType('CCredentials_NewMachineNotificationDialog_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_NewMachineNotificationDialog_Response)
  })
_sym_db.RegisterMessage(CCredentials_NewMachineNotificationDialog_Response)

CCredentials_ValidateEmailAddress_Request = _reflection.GeneratedProtocolMessageType('CCredentials_ValidateEmailAddress_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_ValidateEmailAddress_Request)
  })
_sym_db.RegisterMessage(CCredentials_ValidateEmailAddress_Request)

CCredentials_ValidateEmailAddress_Response = _reflection.GeneratedProtocolMessageType('CCredentials_ValidateEmailAddress_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_ValidateEmailAddress_Response)
  })
_sym_db.RegisterMessage(CCredentials_ValidateEmailAddress_Response)

CCredentials_SteamGuardPhishingReport_Request = _reflection.GeneratedProtocolMessageType('CCredentials_SteamGuardPhishingReport_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_SteamGuardPhishingReport_Request)
  })
_sym_db.RegisterMessage(CCredentials_SteamGuardPhishingReport_Request)

CCredentials_SteamGuardPhishingReport_Response = _reflection.GeneratedProtocolMessageType('CCredentials_SteamGuardPhishingReport_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_SteamGuardPhishingReport_Response)
  })
_sym_db.RegisterMessage(CCredentials_SteamGuardPhishingReport_Response)

CCredentials_LastCredentialChangeTime_Request = _reflection.GeneratedProtocolMessageType('CCredentials_LastCredentialChangeTime_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_LastCredentialChangeTime_Request)
  })
_sym_db.RegisterMessage(CCredentials_LastCredentialChangeTime_Request)

CCredentials_LastCredentialChangeTime_Response = _reflection.GeneratedProtocolMessageType('CCredentials_LastCredentialChangeTime_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_LastCredentialChangeTime_Response)
  })
_sym_db.RegisterMessage(CCredentials_LastCredentialChangeTime_Response)

CCredentials_GetAccountAuthSecret_Request = _reflection.GeneratedProtocolMessageType('CCredentials_GetAccountAuthSecret_Request', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetAccountAuthSecret_Request)
  })
_sym_db.RegisterMessage(CCredentials_GetAccountAuthSecret_Request)

CCredentials_GetAccountAuthSecret_Response = _reflection.GeneratedProtocolMessageType('CCredentials_GetAccountAuthSecret_Response', (_message.Message,), {
  'DESCRIPTOR' : _CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE,
  '__module__' : 'steammessages_credentials_pb2'
  # @@protoc_insertion_point(class_scope:CCredentials_GetAccountAuthSecret_Response)
  })
_sym_db.RegisterMessage(CCredentials_GetAccountAuthSecret_Response)


DESCRIPTOR._options = None
_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['include_new_authentications']._options = None
_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST.fields_by_name['webcookie']._options = None

_CREDENTIALS = _descriptor.ServiceDescriptor(
  name='Credentials',
  full_name='Credentials',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\023Credentials service',
  create_key=_descriptor._internal_create_key,
  serialized_start=2961,
  serialized_end=4094,
  methods=[
  _descriptor.MethodDescriptor(
    name='TestAvailablePassword',
    full_name='Credentials.TestAvailablePassword',
    index=0,
    containing_service=None,
    input_type=_CCREDENTIALS_TESTAVAILABLEPASSWORD_REQUEST,
    output_type=_CCREDENTIALS_TESTAVAILABLEPASSWORD_RESPONSE,
    serialized_options=b'\202\265\030\026TestAvailablePassword.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSteamGuardDetails',
    full_name='Credentials.GetSteamGuardDetails',
    index=1,
    containing_service=None,
    input_type=_CCREDENTIALS_GETSTEAMGUARDDETAILS_REQUEST,
    output_type=_CCREDENTIALS_GETSTEAMGUARDDETAILS_RESPONSE,
    serialized_options=b'\202\265\030\025GetSteamGuardDetails.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewMachineNotificationDialogResult',
    full_name='Credentials.NewMachineNotificationDialogResult',
    index=2,
    containing_service=None,
    input_type=_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_REQUEST,
    output_type=_CCREDENTIALS_NEWMACHINENOTIFICATIONDIALOG_RESPONSE,
    serialized_options=b'\202\265\030#NewMachineNotificationDialogResult.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateEmailAddress',
    full_name='Credentials.ValidateEmailAddress',
    index=3,
    containing_service=None,
    input_type=_CCREDENTIALS_VALIDATEEMAILADDRESS_REQUEST,
    output_type=_CCREDENTIALS_VALIDATEEMAILADDRESS_RESPONSE,
    serialized_options=b'\202\265\030\'Validate an email address given a token',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SteamGuardPhishingReport',
    full_name='Credentials.SteamGuardPhishingReport',
    index=4,
    containing_service=None,
    input_type=_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_REQUEST,
    output_type=_CCREDENTIALS_STEAMGUARDPHISHINGREPORT_RESPONSE,
    serialized_options=b'\202\265\030\030SteamGuardPhishingReport',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCredentialChangeTimeDetails',
    full_name='Credentials.GetCredentialChangeTimeDetails',
    index=5,
    containing_service=None,
    input_type=_CCREDENTIALS_LASTCREDENTIALCHANGETIME_REQUEST,
    output_type=_CCREDENTIALS_LASTCREDENTIALCHANGETIME_RESPONSE,
    serialized_options=b'\202\265\030\037GetCredentialChangeTimeDetails.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountAuthSecret',
    full_name='Credentials.GetAccountAuthSecret',
    index=6,
    containing_service=None,
    input_type=_CCREDENTIALS_GETACCOUNTAUTHSECRET_REQUEST,
    output_type=_CCREDENTIALS_GETACCOUNTAUTHSECRET_RESPONSE,
    serialized_options=b'\202\265\030\024GetAccountAuthSecret',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CREDENTIALS)

DESCRIPTOR.services_by_name['Credentials'] = _CREDENTIALS

Credentials = service_reflection.GeneratedServiceType('Credentials', (_service.Service,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'steammessages_credentials_pb2'
  ))

Credentials_Stub = service_reflection.GeneratedServiceStubType('Credentials_Stub', (Credentials,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'steammessages_credentials_pb2'
  ))


# @@protoc_insertion_point(module_scope)



import fnmatch
from steam.core.msg.unified import get_um
from steam.core.msg.structs import get_struct
from steam.core.msg.headers import MsgHdr, ExtendedMsgHdr, MsgHdrProtoBuf, GCMsgHdr, GCMsgHdrProto
from steam.enums import EResult
from steam.enums.emsg import EMsg
from steam.exceptions import SteamError
from steam.core.msg.structs import StructMessage as _StructMessage
from google.protobuf.message import Message as _ProtoMessageType
from steam.protobufs import steammessages_base_pb2
from steam.protobufs import steammessages_clientserver_pb2
from steam.protobufs import steammessages_clientserver_2_pb2
from steam.protobufs import steammessages_clientserver_friends_pb2
from steam.protobufs import steammessages_clientserver_login_pb2
from steam.protobufs import steammessages_clientserver_appinfo_pb2
from steam.protobufs import steammessages_clientserver_gameservers_pb2
from steam.protobufs import steammessages_clientserver_lbs_pb2
from steam.protobufs import steammessages_clientserver_mms_pb2
from steam.protobufs import steammessages_clientserver_ucm_pb2
from steam.protobufs import steammessages_clientserver_uds_pb2
from steam.protobufs import steammessages_clientserver_ufs_pb2
from steam.protobufs import steammessages_clientserver_userstats_pb2


cmsg_lookup_predefined = {
    EMsg.Multi: steammessages_base_pb2.CMsgMulti,
    EMsg.ClientToGC: steammessages_clientserver_2_pb2.CMsgGCClient,
    EMsg.ClientFromGC: steammessages_clientserver_2_pb2.CMsgGCClient,
    EMsg.ClientServiceMethodLegacy: steammessages_clientserver_2_pb2.CMsgClientServiceMethodLegacy,
    EMsg.ClientServiceMethodLegacyResponse: steammessages_clientserver_2_pb2.CMsgClientServiceMethodLegacyResponse,
    EMsg.ClientGetNumberOfCurrentPlayersDP: steammessages_clientserver_2_pb2.CMsgDPGetNumberOfCurrentPlayers,
    EMsg.ClientGetNumberOfCurrentPlayersDPResponse: steammessages_clientserver_2_pb2.CMsgDPGetNumberOfCurrentPlayersResponse,
#   EMsg.ClientEmailChange4: steammessages_clientserver_2_pb2.CMsgClientEmailChange,
#   EMsg.ClientEmailChangeResponse4: steammessages_clientserver_2_pb2.CMsgClientEmailChangeResponse,
    EMsg.ClientLogonGameServer: steammessages_clientserver_login_pb2.CMsgClientLogon,
    EMsg.ClientCurrentUIMode: steammessages_clientserver_2_pb2.CMsgClientUIMode,
    EMsg.ClientChatOfflineMessageNotification: steammessages_clientserver_2_pb2.CMsgClientOfflineMessageNotification,
}

cmsg_lookup = dict()

for proto_module in [
                    steammessages_clientserver_pb2,
                    steammessages_clientserver_2_pb2,
                    steammessages_clientserver_friends_pb2,
                    steammessages_clientserver_login_pb2,
                    steammessages_clientserver_appinfo_pb2,
                    steammessages_clientserver_gameservers_pb2,
                    steammessages_clientserver_lbs_pb2,
                    steammessages_clientserver_mms_pb2,
                    steammessages_clientserver_ucm_pb2,
                    steammessages_clientserver_uds_pb2,
                    steammessages_clientserver_ufs_pb2,
                    steammessages_clientserver_userstats_pb2,
                    ]:
    cmsg_list = proto_module.__dict__
    cmsg_list = fnmatch.filter(cmsg_list, 'CMsg*')
    cmsg_lookup.update(dict(zip(map(lambda cmsg_name: cmsg_name.lower(), cmsg_list),
                                map(lambda cmsg_name: getattr(proto_module, cmsg_name), cmsg_list)
                               )))


def get_cmsg(emsg):
    """Get protobuf for a given EMsg

    :param emsg: EMsg
    :type  emsg: :class:`steam.enums.emsg.EMsg`, :class:`int`
    :return: protobuf message
    """
    if not isinstance(emsg, EMsg):
        emsg = EMsg(emsg)

    if emsg in cmsg_lookup_predefined:
        return cmsg_lookup_predefined[emsg]
    else:
        enum_name = emsg.name.lower()
        if enum_name.startswith("econ"):  # special case for 'EconTrading_'
            enum_name = enum_name[4:]
        cmsg_name = "cmsg" + enum_name

    return cmsg_lookup.get(cmsg_name, None)

class Msg(object):
    proto = False
    body = None     #: message instance
    payload = None  #: Will contain body payload, if we fail to find correct message class

    def __init__(self, msg, data=None, extended=False, parse=True):
        self.extended = extended
        self.header = ExtendedMsgHdr(data) if extended else MsgHdr(data)
        self.msg = msg

        if data:
            self.payload = data[self.header._size:]

        if parse:
            self.parse()

    def parse(self):
        """Parses :attr:`payload` into :attr:`body` instance"""
        if self.body is None:
            deserializer = get_struct(self.msg)

            if deserializer:
                self.body = deserializer(self.payload)
                self.payload = None
            else:
                self.body = '!!! Failed to resolve message !!!'

    @property
    def msg(self):
        return self.header.msg

    @msg.setter
    def msg(self, value):
        self.header.msg = EMsg(value)

    def serialize(self):
        return self.header.serialize() + self.body.serialize()

    @property
    def steamID(self):
        return (self.header.steamID
                if isinstance(self.header, ExtendedMsgHdr)
                else None
                )

    @steamID.setter
    def steamID(self, value):
        if isinstance(self.header, ExtendedMsgHdr):
            self.header.steamID = value

    @property
    def sessionID(self):
        return (self.header.sessionID
                if isinstance(self.header, ExtendedMsgHdr)
                else None
                )

    @sessionID.setter
    def sessionID(self, value):
        if isinstance(self.header, ExtendedMsgHdr):
            self.header.sessionID = value

    def __repr__(self):
        if isinstance(self.body, _StructMessage):
            suffix = self.body.__class__.__name__
        elif self.payload:
            suffix = 'not parsed'
        else:
            suffix = 'n/a'

        return "<Msg(%r | %s)>" % (self.msg, suffix)

    def __str__(self):
        rows = [repr(self)]

        header = str(self.header)
        rows.append("-------------- header --")
        rows.append(header if header else "(empty)")

        body = str(self.body)
        rows.append("---------------- body --")
        rows.append(body if body else "(empty)")

        if self.payload:
            rows.append("------------- payload --")
            rows.append(repr(self.payload))

        return '\n'.join(rows)


class MsgProto(object):
    proto = True
    body = None     #: protobuf message instance
    payload = None  #: Will contain body payload, if we fail to find correct proto message

    def __init__(self, msg, data=None, parse=True):
        self._header = MsgHdrProtoBuf(data)
        self.header = self._header.proto
        self.msg = msg

        if data:
            self.payload = data[self._header._fullsize:]

        if parse:
            self.parse()

    def parse(self):
        """Parses :attr:`payload` into :attr:`body` instance"""
        if self.body is None:
            if self.msg in (EMsg.ServiceMethod, EMsg.ServiceMethodResponse, EMsg.ServiceMethodSendToClient):
                is_resp = False if self.msg == EMsg.ServiceMethod else True
                proto = get_um(self.header.target_job_name, response=is_resp)
            else:
                proto = get_cmsg(self.msg)

            if proto:
                self.body = proto()
                if self.payload:
                    self.body.ParseFromString(self.payload)
                    self.payload = None
            else:
                self.body = '!!! Failed to resolve message !!!'

    @property
    def msg(self):
        return self._header.msg

    @msg.setter
    def msg(self, value):
        self._header.msg = EMsg(value)

    def serialize(self):
        return self._header.serialize() + self.body.SerializeToString()

    @property
    def steamID(self):
        return self.header.steamid

    @steamID.setter
    def steamID(self, value):
        self.header.steamid = value

    @property
    def sessionID(self):
        return self.header.client_sessionid

    @sessionID.setter
    def sessionID(self, value):
        self.header.client_sessionid = value

    def __repr__(self):
        if isinstance(self.body, _ProtoMessageType):
            suffix = self.body.__class__.__name__
        elif self.payload:
            suffix = 'not parsed'
        else:
            suffix = 'n/a'

        return "<MsgProto(%r | %s)>" % (self.msg, suffix)

    def __str__(self):
        rows = [repr(self)]

        header = str(self.header).rstrip()
        rows.append("-------------- header --")
        rows.append(header if header else "(empty)")

        body = str(self.body).rstrip()
        rows.append("---------------- body --")
        rows.append(body if body else "(empty)")

        if self.payload:
            rows.append("------------- payload --")
            rows.append(repr(self.payload))

        return '\n'.join(rows)

